@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2013 Fanficdownloader team, 2018 FanFicFare team
+# Copyright 2013 Fanficdownloader team, 2019 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ from __future__ import absolute_import
 import logging
 logger = logging.getLogger(__name__)
 import re
+from datetime import datetime
 #
 from ..htmlcleanup import stripHTML
 from .. import exceptions as exceptions
@@ -87,7 +88,8 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                 or "Invalid Password!" in data \
                 or "Invalid User Name!" in data \
                 or "Log In" in data \
-                or "Access to unlinked chapters requires" in data:
+                or "Access to unlinked chapters requires" in data \
+                or "Log in to Storiesonline" in data :
             self.needToLogin = True
         return self.needToLogin
 
@@ -106,15 +108,20 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         loginUrl = 'https://' + self.getSiteDomain() + '/sol-secure/login.php'
         logger.debug("Will now login to URL (%s) as (%s)" % (loginUrl,
                                                               params['theusername']))
+
+        if not params['theusername'] or not params['thepassword']:
+            logger.info("Login Required for URL %s" % loginUrl)
+            raise exceptions.FailedToLogin(url,params['theusername'])
+
         try:
             d = self._postUrl(loginUrl,params,usecache=False)
+            self.needToLogin = False
         except HTTPError as e:
             if e.code == 307:
                 logger.debug("HTTP Error 307: Temporary Redirect -- assumed to be valid login for this site")
                 return True
 
-        # probably not used now, 307 seems standard now for storiesonline.net/finestories.com
-        if "My Account" not in d : #Member Account
+        if self.needToLoginCheck(d):
             logger.info("Failed to login to URL %s as %s" % (loginUrl,
                                                               params['theusername']))
             raise exceptions.FailedToLogin(url,params['theusername'])
@@ -306,7 +313,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                 if series_soup:
                     # logger.debug("Retrieving Series - looking for name")
                     series_name = stripHTML(series_soup.find('h1', {'id' : 'ptitle'}))
-                    series_name = re.sub(r' . a series by.*$','',series_name)
+                    series_name = re.sub(r' . a (series by|collection from).*$','',series_name)
                     # logger.debug("Series name: '%s'" % series_name)
                 self.setSeries(series_name, i)
                 desc = description_element.contents[2]
@@ -375,13 +382,29 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
 
         self.setDescription('https://'+self.host+'/s/'+self.story.getMetadata('storyId'),desc)
 
+    def parseDate(self,label):
+        # date is passed as a timestamp and converted in JS.  used to
+        # use noscript value instead, but found one story that didn't
+        # include it.
+        # logger.debug('parseDate: "%s"' % label)
+        noscript = label.findNext('noscript').text
+        try:
+            timestamp = label.findNext('script').text
+            timestamp = timestamp[timestamp.index("Date(")+5:]
+            # remove milliseconds that JS likes.
+            timestamp = timestamp[:timestamp.index(")")-3]
+            value = datetime.fromtimestamp(float(timestamp))
+        except:
+            value = makeDate(stripHTML(noscript), self.dateformat)
+        # logger.debug('Have a date field label: "%s", noscript: "%s", timestamp: "%s", value: "%s"' % (label, noscript, timestamp, value))
+        return value
 
     def parseOtherAttributes(self, other_attribute_element):
         for b in other_attribute_element.findAll('b'):
             #logger.debug('Getting metadata: "%s"' % b)
             label = b.text
             if label in ['Posted:', 'Concluded:', 'Updated:']:
-                value = b.findNext('noscript').text
+                value = self.parseDate(b)
                 #logger.debug('Have a date field label: "%s", value: "%s"' % (label, value))
             else:
                 value = b.nextSibling
@@ -400,12 +423,12 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                     self.story.addToList('genre', code)
 
             if 'Posted' in label:
-                self.story.setMetadata('datePublished', makeDate(stripHTML(value), self.dateformat))
-                self.story.setMetadata('dateUpdated', makeDate(stripHTML(value), self.dateformat))
+                self.story.setMetadata('datePublished', value)
+                self.story.setMetadata('dateUpdated', value)
             if 'Concluded' in label:
-                self.story.setMetadata('dateUpdated', makeDate(stripHTML(value), self.dateformat))
+                self.story.setMetadata('dateUpdated', value)
             if 'Updated' in label:
-                self.story.setMetadata('dateUpdated', makeDate(stripHTML(value), self.dateformat))
+                self.story.setMetadata('dateUpdated', value)
 
         status = other_attribute_element.find('span', {'class':'ab'})
         if status != None:
@@ -414,9 +437,7 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             else:
                 self.story.setMetadata('status', 'In-Progress')
             if "Last Activity" in status.text:
-                # date is passed as a timestamp and converted in JS.
-                value = status.findNext('noscript').text
-                self.story.setMetadata('dateUpdated', makeDate(stripHTML(value), self.dateformat))
+                self.story.setMetadata('dateUpdated', value)
         else:
             self.story.setMetadata('status', 'Completed')
 
