@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015 Fanficdownloader team, 2018 FanFicFare team
+# Copyright 2015 Fanficdownloader team, 2019 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -115,6 +115,7 @@ titleLabels = {
     'numWords':'Words',
     'words_added':'Words Added', # logpage only
     'site':'Site',
+    'publisher':'Publisher',
     'storyId':'Story ID',
     'authorId':'Author ID',
     'extratags':'Extra Tags',
@@ -296,6 +297,7 @@ def get_valid_scalar_entries():
                  'numWords',
                  'words_added', # logpage only.
                  'site',
+                 'publisher',
                  'storyId',
                  'title',
                  'titleHTML',
@@ -684,8 +686,7 @@ class Configuration(configparser.SafeConfigParser):
     # split and strip each.
     def get_config_list(self, sections, key, default=[]):
         vlist = re.split(r'(?<!\\),',self.get_config(sections,key)) # don't split on \,
-        # was filter( lambda x : x !='', [ v.strip().replace('\,',',') for v in vlist ])
-        vlist = vlist = [x for x in [ v.strip().replace('\,',',') for v in vlist ] if x !='']
+        vlist = [x for x in [ v.strip().replace('\,',',') for v in vlist ] if x !='']
         #print("vlist("+key+"):"+unicode(vlist))
         if not vlist:
             return default
@@ -1054,6 +1055,12 @@ class Configuration(configparser.SafeConfigParser):
             headers['Content-type']='application/x-www-form-urlencoded'
         if 'Accept' not in headers:
             headers['Accept']="text/html,*/*"
+
+        # if "xf2test" in url:
+        #     import base64
+        #     base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
+        #     headers['Authorization']=b"Basic %s" % base64string
+
         req = Request(url,
                       data=ensure_binary(urlencode(parameters)),
                       headers=headers)
@@ -1122,6 +1129,11 @@ class Configuration(configparser.SafeConfigParser):
             ## not present at all
             headers.append(('Referer',referer))
 
+        # if "xf2test" in url:
+        #     import base64
+        #     base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
+        #     headers.append(('Authorization', b"Basic %s" % base64string))
+
         self.opener.addheaders = headers
 
         if parameters != None:
@@ -1182,6 +1194,7 @@ class Configuration(configparser.SafeConfigParser):
             except Exception as e:
                 excpt=e
                 logger.debug("Caught an exception reading URL: %s sleeptime(%s) Exception %s."%(unicode(safe_url(url)),sleeptime,unicode(e)))
+                raise
 
         logger.debug("Giving up on %s" %safe_url(url))
         logger.debug(excpt, exc_info=True)
